summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormichael5 chen <michael5_chen@pegatroncorp.com>2019-01-25 17:51:20 +0800
committerChromeOS Commit Bot <chromeos-commit-bot@chromium.org>2019-01-29 02:18:43 +0000
commit49e76742868f872bcb7a02f98165d3a290eb09c0 (patch)
treece8ff50fa1e910eacd0fcf80b4d15d02168c4555
parent6a9f75a3b2a18634ae4e965578787d1162bc2f28 (diff)
downloadchrome-ec-49e76742868f872bcb7a02f98165d3a290eb09c0.tar.gz
rammus: Reduce adapter charger current limit setting
Modify adapter charger current limit to 92% of adapter current to reduce charge current. BUG=b:123379983 BRANCH=firmware-rammus-11275 TEST=Manual Using ectool i2cread to check charger setting. (0xac0) ASUS check charge current less than 3A. The test result is pass. Change-Id: I49bb8e5007df1b10fc63c9577a82f4ceb174d118 Signed-off-by: michael5 chen <michael5_chen@pegatroncorp.com> Reviewed-on: https://chromium-review.googlesource.com/c/1436716 Reviewed-by: Zhuohao Lee <zhuohao@chromium.org>
-rw-r--r--board/rammus/board.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/rammus/board.c b/board/rammus/board.c
index 46afccbb2f..8ed124050d 100644
--- a/board/rammus/board.c
+++ b/board/rammus/board.c
@@ -526,10 +526,10 @@ void board_set_charge_limit(int port, int supplier, int charge_ma,
int max_ma, int charge_mv)
{
/*
* Limit the input current to 96% negotiated limit,
* to account for the charger chip margin.
*/
- charge_ma = charge_ma * 96 / 100;
+ charge_ma = charge_ma * 92 / 100;
charge_set_input_current_limit(
MAX(charge_ma, CONFIG_CHARGER_INPUT_CURRENT),
charge_mv);
@@ -526,10 +526,10 @@ void board_set_charge_limit(int port, int supplier, int charge_ma,
{
/*
- * Limit the input current to 96% negotiated limit,
+ * Limit the input current to 92% negotiated limit,
* to account for the charger chip margin.
*/